(function ($, Drupal, window, document, drupalSettings) {
  Drupal.behaviors.paragraph_locator_checkbox = {
    attach(context) {
      function ConfirmPopup(body, popupTitle, selectedItemsArray) {
        const content = body;
        const route = drupalSettings.paragraph_locator.route;
        const confirmationDialog = Drupal.dialog(content, {
          dialogClass: 'confirm-dialog',
          resizable: true,
          closeOnEscape: false,
          width: 600,
          title: popupTitle,
          buttons: [
            {
              text: Drupal.t('Confirm'),
              class: 'btn btn-primary',
              click() {
                $.ajax({
                  url: route,
                  type: 'POST',
                  data: {
                    data: selectedItemsArray,
                  },
                  dataType: 'json',
                  success(data) {
                    window.location.reload(true);
                  },
                  error() {
                    console.log(
                      'An unexpected error occurred. Please try again later.',
                    );
                  },
                });
              },
            },
            {
              text: Drupal.t('Close'),
              class: 'btn btn-secondary',
              click() {
                $(this).dialog('close');
                $('.ui-widget-overlay').hide();
              },
            },
          ],
        });
        confirmationDialog.showModal();
      }

      // Toggle the Delete button on initial checkbox selection.
      function toggleButtons() {
        const checkedItemsCount = $(
          '.paragraph-locator-checkbox:checked',
        ).length;
        if (checkedItemsCount === 0) {
          $('#paragraph-locator-checkbox-delete').attr('disabled', true).hide();
          const feedIcon = $('.feed-icon')[0];
          if (feedIcon) {
            feedIcon.style.pointerEvents = 'auto';
            $(feedIcon).show();
          }
        } else {
          $('#paragraph-locator-checkbox-delete')
            .attr('disabled', false)
            .show();
          const feedIcon = $('.feed-icon')[0];
          if (feedIcon) {
            feedIcon.style.pointerEvents = 'none';
            $(feedIcon).hide();
          }
        }
      }

      // Initial toggle.
      toggleButtons();

      // Toggle on checkbox click.
      $('.paragraph-locator-checkbox').click(function () {
        toggleButtons();
      });

      // Triggers the confirm popup.
      $(
        once(
          'paragraph-locator-checkbox-delete',
          '#paragraph-locator-checkbox-delete',
        ),
      ).click(function () {
        const body = `<div>${Drupal.t('Are you sure you want to delete the selected <b>paragraph(s)</b>? <br><br><b>This action cannot be Undone.</b>')}</div>`;
        const popupTitle = Drupal.t('Please confirm');
        const selectedItemsArray = [];
        const selected = Array.from(
          document.querySelectorAll('.paragraph-locator-checkbox:checked'),
        );
        selected.forEach((element) => {
          const currentItem = {};
          currentItem.value = element.getAttribute('value');
          currentItem.parent = element.getAttribute('parent');
          selectedItemsArray.push(currentItem);
        });
        ConfirmPopup(body, popupTitle, selectedItemsArray);
      });
    },
  };
})(jQuery, Drupal, window, document, drupalSettings);
