<?php

namespace Drupal\paragraph_locator;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class to create a custom service including helper functions.
 */
class ParagraphLocatorHelper {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new ParagraphLocatorHelper object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * Helper function to recursively load the parent entity.
   *
   * @param string $id
   *   The paragraph id.
   *
   * @return mixed|null
   *   Returns the parent entity if any otherwise NULL.
   */
  public function getParentEntity($id) {
    // Check if the entity has a parent.
    if ($id) {
      $paragraph = $this->entityTypeManager->getStorage('paragraph')->load($id);
      if ($paragraph->parent_type->value == 'paragraph') {
        return $this->getParentEntity($paragraph->parent_id->value);
      }
      return [
        'type' => $paragraph->parent_type->value,
        'id' => $paragraph->parent_id->value,
      ];
    }

    return NULL;
  }

}
